<?php

/**
 * LoginForm class.
 * LoginForm is the data structure for keeping
 * user login form data. It is used by the 'login' action of 'SiteController'.
 */
class TestForm extends CFormModel
{
	public $username;
	public $password;
	public $password_repeat;
	public $rememberMe;
	public $verifyCode;
	public $approvePolicy;
	public $favcolor;
	public $custom1;
	public $email;

	/**
	 * Declares the validation rules.
	 * The rules state that username and password are required,
	 * and password needs to be authenticated.
	 */
	public function rules()
	{
		return array(
			
			// form1
			array('username', 'required', 'on' => array('form1','form2','form4')),
			
			array('password', 'required', 'on' => 'form1,form2, form3'),			
			array('password', 'length' ,'min' => 2, 'max' => 10 ,'on' => 'form2'),
			array('approvePolicy', 'required' ,'message' => 'Please approve our policy <br/>' ,'on' => 'form3, form4'),
			array('favcolor', 'required' ,'on' => 'form4,form5'),
			array('custom1', 'required' ,'on' => 'form3'),
			
			// rule below uses a validator provided with the extension. This validator always return true when 
			// called in the Yii framework. It is only used to add client-side validation rules that are not (yet)
			// implemented as a Yii validator class.
			
			array('custom1', 'application.extensions.jformvalidate.ECustomJsValidator' ,'on' => 'form3',
				'rules'    => array(
					'min' => 5
				),
				'messages' => array(
					'min' => '{attribute} : enter a numerical value greater than 4 '
				)
			),
				
			// ajax remote call to test email uniqueness
			
			array('email', 'required' ,'on' => 'form7'),
			array('email', 'email' ,'on' => 'form7'),
			array('email', 'application.extensions.jformvalidate.ECustomJsValidator' ,'on' => 'form7',
				'rules'    => array(
					'remote' => 'index.php?r=JSVForm/remoteValidate'
				),
				'messages' => array(
					'remote' => '{attribute} already registred'
				)
			),	
			// scenario 8 : the COMPARE validator.
			// Note that if the COMPARE rule does not define any value for the compareAttribute
			// parameter, then by default, Yii is going to assume that the password field
			// will be compared to the password_repeat field.
			array('password,username', 'required', 'on' => 'form8'),
			//array('password','compare', 'on' => 'form8'),
			array('password','compare', 'compareAttribute' => 'password_repeat', 'message' => 'please re-enter password', 'on' => 'form8'),
			array('username','compare', 'compareValue' => 'yii', 'message' => 'please enter "yii" as {attribute}', 'on' => 'form8')
		);
	}

	/**
	 * Declares attribute labels.
	 * If not declared here, an attribute would have a label
	 * the same as its name with the first letter in upper case.
	 */
	public function attributeLabels()
	{
		return array(
			'verifyCode'=>'Verification Code',
			'custom1' => 'Custom Field',
			'password_confirm' => 'Confirm password'
		);
	}

	/**
	 * Authenticates the password.
	 * This is the 'authenticate' validator as declared in rules().
	 */
	public function authenticate($attribute,$params)
	{
		$this->addError('password','Incorrect password.');
	}
	public function isUniqueMail()
	{
		return ($this->email == "user@yii.com");
	}
}
